Nested Data and Nested Iteration
::::::::::::::::::::::::::::::::

.. toctree::
   :caption: Nested Data and Nested Iteration
   :maxdepth: 2

   ListswithComplexItems.rst
   NestedDictionaries.rst
   jsonlib.rst
   NestedIteration.rst
   WPStructuringNestedData.rst
   DeepandShallowCopies.rst
   WPExtractFromNestedData.rst
   Exercises.rst
   ChapterAssessment.rst

   
   